Django Staff v 1.0 — django-staff 1.0 documentation

django-staff 1.0 documentation

# Django Staff v 1.0

- Table of Contents
- index
  next

# Django Staff v 1.0

## Goals

In the Django Authentication package all users use the same model/profile. This can be a drawback if you have lots of users and you want different information stored for your staff members, such as bio, contact info, etc. It is also handy for linking to models for author fields so the lookup is quicker.

The staff models are automatically created and managed by the `is_staff` property of `Users`. The staff profile is automatically added to the `User` admin screen.

## Contents

- Getting Started
  - Installation
  - How it works
  - Using Django Staff
- Customizing StaffMember
  - Create the custom class
  - Connect the signal
  - Create your admin class
  - Gather the templates
  - Remove staff from INSTALLED_APPS
- Reference
  - Settings
  - Staff Model Reference

## Indices and tables

- Index
- Module Index
- Search Page